@@ -1,4 +1,4 @@
-chebyshev.s.quadrature.rules <- function( n )
+chebyshev.s.quadrature.rules <- function( n, normalized=FALSE )
 {
 ###
 ### This function returns a list with n elements
@@ -10,9 +10,13 @@ chebyshev.s.quadrature.rules <- function( n )
 ###
 ### Parameter
 ### n = integer highest order
+### normalized = boolean value.  If TRUE, recurrences are for normalized polynomials
 ###
-    require( orthopolynom )
-    recurrences <- chebyshev.s.recurrences( n )
+    if ( n <= 0 )
+        stop( "highest order is not positive" )
+    if ( n != round( n ) )
+        stop( "highest order is not an integer" )
+    recurrences <- chebyshev.s.recurrences( n, normalized )
     inner.products <- chebyshev.s.inner.products( n )
     return( quadrature.rules( recurrences, inner.products ) )
 }
