@@ -1,4 +1,4 @@
-gegenbauer.quadrature.rules <- function( n, alpha )
+gegenbauer.quadrature.rules <- function( n, alpha, normalized=FALSE )
 {
 ###
 ### This function returns a list with n elements
@@ -10,15 +10,23 @@ gegenbauer.quadrature.rules <- function( n, alpha )
 ### Parameters
 ### n = integer highest order
 ### alpha = polynomial parameter
+### normalized = boolean value.  If TRUE, recurrences are for normalized polynomials
+###
+### alpha = 0.5
+### special case is the Legendre polynomial
 ###
-    require( orthopolynom )
-    if ( abs( alpha ) < 1e-6 )
-        return( chebyshev.t.quadrature.rules( n ) )
     if ( abs( alpha - 0.5 ) < 1e-6 )
-        return( legendre.quadrature.rules( n ) )
+        return( legendre.quadrature.rules( n, normalized ) )
+###
+### alpha = 1.0
+### special case is the Chebyshev polynomial of the second kind U
+###
     if ( abs( alpha - 1.0 ) < 1e-6 )
-        return( chebyshev.u.quadrature.rules( n ) )
-    recurrences <- gegenbauer.recurrences( n, alpha )
+        return( chebyshev.u.quadrature.rules( n, normalized ) )
+###
+### all other cases including alpha = 0
+###
+    recurrences <- gegenbauer.recurrences( n, alpha, normalized )
     inner.products <- gegenbauer.inner.products( n, alpha )
     return( quadrature.rules( recurrences, inner.products ) )
 }
